@@ -19,7 +19,7 @@ def poetry_build(build_dest: Union[Path, str], pyproject_path: Union[Path, str])
     # Modify the project name so that it does not override environment for the actual project
 
     project_name = pyproject["tool"]["poetry"]["name"]
-    alt_project_name = f"{pyproject['tool']['poetry']['name']}_{run_key}"
+    alt_project_name = f"{pyproject['tool']['poetry']['name']}-{run_key}"
     pyproject["tool"]["poetry"]["name"] = alt_project_name
 
     op_dir = Path(tmp_dir, project_name)
@@ -37,3 +37,5 @@ def poetry_build(build_dest: Union[Path, str], pyproject_path: Union[Path, str])
     # Copy the packages and actual source code to folder
     typer.echo("Copying installed packages...")
     shutil.copytree(packages_folder, build_dest, dirs_exist_ok=True)
+    typer.echo("Removing temporary poetry init directory..")
+    shutil.rmtree(packages_dir, ignore_errors=True)
